@@ -480,7 +480,7 @@ class VirtualService(HttpClient, KempBaseObjectModel):
         self.cookie = service.get('Cookie', None)
         self.extraports = service.get('ExtraPorts', None)
         self.qos = service.get('QoS', None)
-        self.idletime = service.get('IdleTime', None)
+        self.idletime = service.get('Idletime', None)
 
     def create_real_server(self, ip, port=80):
         """RealServer factory with pre-configured LoadMaster connection."""
